--[[
FileName 		TableLoadingLayer.lua
ProjectName		HJ2

Created by wangming on 16-08-16
    
]]

local TableLoadingLayer = class("TableLoadingLayer", function(params)
    return ZCDialog:create()
end)

function TableLoadingLayer:create(params)
	local _loading = TableLoadingLayer.new(params)
	local _scene = cc.Director:getInstance():getRunningScene()
	if params.par then
		_scene = params.par
	end
	if _scene then
	    _scene:addChild(_loading, 100)
	end
    return _loading
end


function TableLoadingLayer:ctor( params )
    self._status = 0
    self._isUpGtStart = params.googleFlag == nil and false or params.googleFlag
	self._onlyLoading = params.onlyLoading == nil and true or params.onlyLoading
	self._successCall = params.successCallback
	self._failCall = params.failedCallback
	if self._onlyLoading then
		local _circle = LoadingCircleLayer:create(true)
		self:addChild(_circle, 1)
		self:setOpacity(0)
	end
end

function TableLoadingLayer:initFullUI()
    if self._onlyLoading then
        return
    end

    local bar_bg = zc.createSprite("res/image/update/barBg.png")
    bar_bg:setPosition(cc.p(zc.width / 2, 55))
    self:addChild(bar_bg)

    local loadingProgress = cc.ProgressTimer:create(cc.Sprite:create("res/image/update/bar.png"))
    loadingProgress:setType(cc.PROGRESS_TIMER_TYPE_BAR)
    loadingProgress:setMidpoint(cc.p(0, 0))
    loadingProgress:setBarChangeRate(cc.p(1, 0))
    loadingProgress:setPosition(cc.p(bar_bg:getContentSize().width / 2, bar_bg:getContentSize().height / 2))
    loadingProgress:setPercentage(0)
    bar_bg:addChild(loadingProgress)
    self._loadingProgress = loadingProgress

    --loading标签
    if not APP_REVIEW then
        local loading = zc.createSprite("res/image/update/LOADING.png")
        loading:setAnchorPoint(0.5, 0.5)
        loading:setPosition(zc.width/2, 32)
        self:addChild(loading)
    end
end

function TableLoadingLayer:doSuccessCall()
	local _successCall = self._successCall
    if not self._isUpGtStart then
    	local _global = package.loaded
        for key, value in pairs(_global) do
            if string.find(tostring(key), "/staticData/") and string.find(tostring(key), ".lua") then
                print("---------------------->"..tostring(key))
                package.loaded[key] = nil;   --赋值为nil的目的是为了重新加载.lua文件，值为true是标记已经加载过了
            end
        end
    end
    gameData.reset()
	self:removeFromParent()
	if _successCall then
		_successCall()
	end
end

function TableLoadingLayer:doFailCall( noUpdate )
	local _failCall = self._failCall
	self:removeFromParent()
	if _failCall then
		_failCall(noUpdate)
	end
end

function TableLoadingLayer:onEnter()
	if self._init then
		return
	end
	self._init = true
	self:checkUpdate()
end

--显示最新版本信息提示页面
function TableLoadingLayer:showAnnouncement(data)

    --创建提示层Layout
    local noticeLayout = cc.LayerColor:create(cc.c4b(0,0,0,150))
    noticeLayout:setTouchEnabled(true)
    noticeLayout:setAnchorPoint(cc.p(0, 0))
    noticeLayout:setPosition(cc.p(0, 0))
    noticeLayout:registerScriptTouchHandler(function ( eventType, x, y )
        if (eventType == "began") then
            return true
        end
    end)
    self:addChild(noticeLayout, 1000)

    --增加提示背景框
    local bg = cc.Sprite:create("res/Main/common/popBg/popup_Bg_blue.png")
    bg:setPosition(cc.p(noticeLayout:getContentSize().width*0.5 , noticeLayout:getContentSize().height*0.5))
    noticeLayout:addChild(bg)
    
    -- 中间背景
    local middleBg = zc.getScaleNode("res/Main/common/popBg/di_1.png", cc.size(460, 200))
    middleBg:setPosition(bg:getContentSize().width*0.5, bg:getContentSize().height*0.5 + 30)
    middleBg:setName("middleBg")
    bg:addChild(middleBg)

    local bgWidth = bg:getContentSize().width
    local bgHeight = bg:getContentSize().height

    local paSize = ""

    local _bgSize = bg:getContentSize()
    local _size = cc.size(_bgSize.width - 130 * 2, _bgSize.height- 58 - 85)
    
    local patchSize = ""
    --处理更新大小
    if data.patchsize ~= nil and data.patchsize > 0 then
        if data.patchsize > (1024 * 1024) then
            self._sizeNum = string.format("%.1f", data.patchsize / (1024 * 1024))
            patchSize = patchSize .. self._sizeNum .. " MB"
        else
            self._sizeNum = string.format("%.1f", data.patchsize / 1024)
            patchSize = patchSize .. self._sizeNum .. " KB"
        end
        paSize = patchSize
        patchSize = LANGUAGE_OTHER_TXTPACKAGESIZE .. patchSize 
    end
    print("paSize ----> ", paSize)

    local tipLab_1 = zc.createLabel({
        text = LANGUAGE_UPDATE_INFO.tip1,
        outLine = true,
        fontSize = 22,
        ap = cc.p(0, 0.5),
        pos = cc.p(30, middleBg:getContentSize().height/2+10),
        pixel = 1.3,
        -- width = 375,
    })
    middleBg:addChild(tipLab_1)
    local tipLab_2 = zc.createLabel({
        text = paSize,
        outLine = true,
        fontSize = 22,
        ap = cc.p(0, 0.5),
        pos = cc.p(tipLab_1:getPositionX() + tipLab_1:getContentSize().width + 5, tipLab_1:getPositionY()),
        color = zc.COLOR_YELLOW,
        pixel = 1.3,
        -- width = 375,
    })
    middleBg:addChild(tipLab_2)
    local tipLab_3 = zc.createLabel({
        text = LANGUAGE_UPDATE_INFO.tip2,
        outLine = true,
        fontSize = 22,
        ap = cc.p(0, 0.5),
        pos = cc.p(tipLab_2:getPositionX() + tipLab_2:getContentSize().width + 5, tipLab_2:getPositionY()),
        pixel = 1.3,
    })
    middleBg:addChild(tipLab_3)
    local tipLab_4 = zc.createLabel({
        text = LANGUAGE_UPDATE_INFO.tip3,
        outLine = true,
        fontSize = 22,
        ap = cc.p(0, 0.5),
        pos = cc.p(tipLab_1:getPositionX(), tipLab_1:getPositionY()-30),
        pixel = 1.3,
    })
    middleBg:addChild(tipLab_4)

    local confirmButton = zc.createCommomBtn({
        tag = 1,
        text = LANGUAGE_UPDATE_INFO.tip6,
        needSwallow = true,
        endCallback = function()
            noticeLayout:setVisible(false)
            self:updateLua()
        end,
        anchor = cc.p(0.5, 0.5),
        pos = cc.p(bgWidth / 2, 70)
    })
    

    bg:addChild(confirmButton)
end

function TableLoadingLayer:checkUpdate()
	--解析本地Manifest文件
    local _flag = self._isUpGtStart == true and 2 or 1
    local manifest = zc.getManifest(_flag)
    -- dump(manifest, "========flag" ..  _flag)
    if not manifest then
        self:doFailCall()
        return
    end

    local testing = ""
    if manifest["testing"] ~= nil then
        testing = "&testing=" .. manifest["testing"]
    end
    -- local _channel = GAME_CHANNEL and tostring(GAME_CHANNEL) or ""
	local _channel = manifest["update_channel"]
    local lastVersionParams = {
        url = manifest["lastVersionUrl"] .. "&bundle=" .. manifest["bundle"] .. "&version=" .. manifest["version"] .. "&update_channel=" .. _channel .. testing,
        successCallback = function(data)
            if data and tonumber(data.status) == 1 then
                self:initFullUI()
                if self._isUpGtStart then
                    self:showAnnouncement(data)
                else
                    self:updateLua()
                end
                return
            end 
	        self:doFailCall(0)
        end,
        failedCallback = function()
	        self:doFailCall(1)
        end,
        errorCallback = function()
	        self:doFailCall(1)
        end,
        isGameApi = false,
        targetNeedsToRetain = self,
        loadingParent = self,
        encrypt = HTTP_ENCRYPT_TYPE.NONE,
    }
    ZCHttp:requestAsyncWithParams(lastVersionParams)
end

function TableLoadingLayer:updateLua()
    -- local am = cc.AssetsManagerEx:createWithChannel("src/staticData/project.manifest", zc.getWritablePath() .. "/src/staticData/", GAME_CHANNEL or "")
    local platform = cc.Application:getInstance():getTargetPlatform()
    local _localFile = "src/staticData/project.manifest"
    local _path = zc.getWritablePath() .. "/src/staticData/"
    if self._isUpGtStart then
        _localFile = "res/google_project.manifest"
        _path = zc.getWritablePath() .. "/res/"
    elseif APP_SERVER == 0 then
        _localFile = "src/staticData/nei_project.manifest"
    else
        local id = zc.getChannelPackageId()
        -- print("id:::::",id)
        if platform == cc.PLATFORM_OS_IPHONE or platform == cc.PLATFORM_OS_IPAD then
            if id == 10 then
                _localFile = "src/staticData/ios_gt_project.manifest"
            elseif id == 2 then
                _localFile = "src/staticData/ios_project.manifest"
            end
        elseif platform == cc.PLATFORM_OS_ANDROID then
            if id == 11 then
                _localFile = "src/staticData/gt_project.manifest"
            else
                _localFile = "src/staticData/project.manifest"
            end
        end
    end
    print("_localFile:",_localFile,"_path:",_path,"id= ",id)
    local am = cc.AssetsManagerEx:create(_localFile, _path)
    am:setPackageUrl(self._status)
    am:retain()

    local listener = nil
    local function _goNormalGo()
    	if listener then
        	cc.Director:getInstance():getEventDispatcher():removeEventListener(listener)
        end
        am:release()

        local isTryAgain = false
        if self._status == 0 then
            self._status = 1 
            isTryAgain = true
        end
        if isTryAgain then
            performWithDelay(self, function()
                self:updateLua()
            end, 0.1)
        else
            self._status = 0
            self:doFailCall(2)
        end
    end
    if self._loadingProgress then
	    self._loadingProgress:setVisible(true)
	end
    local loadingProgressInAction = false
    if not am:getLocalManifest():isLoaded() then
        self._status = 1
        _goNormalGo()
    else
        local function onUpdateEvent(event)
            local eventCode = event:getEventCode()
            if eventCode == cc.EventAssetsManagerEx.EventCode.ERROR_NO_LOCAL_MANIFEST
              or eventCode == cc.EventAssetsManagerEx.EventCode.ERROR_DOWNLOAD_MANIFEST
              or eventCode == cc.EventAssetsManagerEx.EventCode.ERROR_PARSE_MANIFEST 
              or eventCode == cc.EventAssetsManagerEx.EventCode.ERROR_UPDATING 
              or eventCode == cc.EventAssetsManagerEx.EventCode.ERROR_DECOMPRESS
              or eventCode == cc.EventAssetsManagerEx.EventCode.UPDATE_FAILED
              then
                print("更新出错["..tostring(eventCode).."],event:getCURLECode()=["..event:getCURLECode().."],event:getCURLMCode()=["..event:getCURLMCode().."],event:getMessage()=["..tostring(event:getMessage()).."]")
                _goNormalGo()
            elseif  eventCode == cc.EventAssetsManagerEx.EventCode.UPDATE_PROGRESSION then
                local assetId = event:getAssetId()
                local percent = event:getPercent()

                if assetId ~= cc.AssetsManagerExStatic.VERSION_ID and assetId ~= cc.AssetsManagerExStatic.MANIFEST_ID then
                    if loadingProgressInAction == false then
                        cc.Director:getInstance():getActionManager():removeAllActionsFromTarget(self._loadingProgress)
                        loadingProgressInAction = true
                    end

				    if self._loadingProgress then
		                self._loadingProgress:setPercentage(tonumber(percent))
                    end
                end
            elseif eventCode == cc.EventAssetsManagerEx.EventCode.ALREADY_UP_TO_DATE or
                eventCode == cc.EventAssetsManagerEx.EventCode.UPDATE_FINISHED then
                print("更新完成")
                am:release()
                self:doSuccessCall()
            else
                print("*******************更新未完成["..tostring(eventCode).."],event:getCURLECode()=["..event:getCURLECode().."],event:getCURLMCode()=["..event:getCURLMCode().."],event:getMessage()=["..tostring(event:getMessage()).."]")
            end
        end

        listener = cc.EventListenerAssetsManagerEx:create(am,onUpdateEvent)
        cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1)
        am:update()
    end
end

return TableLoadingLayer
