--[[
	奖励兑换活动
]]
local ExchangeLayer = class("ExchangeLayer", function()
    local layer = cc.Sprite:create()
    layer:setContentSize( 720, 463 )
	return layer
end)

function ExchangeLayer:create( params )
	return ExchangeLayer.new( params )
end



function ExchangeLayer:ctor( params )
	local _dbs = params.static or {}
	local _status = params.status or {}
	local _datas = {}
	-- activityType = 2 在限时热点界面 1 表示在活动界面
	self.activityType = params.activityType
	for k,v in pairs(_dbs) do
		local __status = _status[k] or {}
		table.insert(_datas, {
			id = tonumber(v.id) or 0,
			nums = tonumber(__status.nums) or 0,
			item1 = v.needItem1 or "",
			item2 = v.needItem2 or "",
			max = tonumber(v.parameter) or 0,
			item = v.item or "",
			typeDesc = v.type,
			limitType = tonumber(v.limitType) or 0,
		})
	end
	self._datas = _datas
	self:sortData()
	self._tipText = string.split(self._datas[1].typeDesc or "", "|")
	if #self._tipText > 0 then
		self._tipText = table.concat(self._tipText, "、")
	end
	self:initUI()

	local _top = LayerManager.getTopInfoLayer()
	_top:setPopInfo("ActivityExchange")

	self:onNodeEvent("exit", function()
		local _top = LayerManager.getTopInfoLayer()
		_top:setPopInfo("ActivityPop")
    end)
end

function ExchangeLayer:sortData()
    table.sort(self._datas, function( a, b )
    	local _nowCanA = a.max - a.nums
    	local _nowCanB = b.max - b.nums
        if _nowCanA ~= _nowCanB then
            if _nowCanA == 0 and a.limitType ~= 0 then
            	return false
            end
            if _nowCanB == 0 and b.limitType ~= 0 then
            	return true
        	end
        elseif a.limitType ~= b.limitType then
        	if a.limitType == 0 then
            	return true
            end
            if b.limitType == 0 then
            	return false
            end
        end
        return a.id < b.id
    end)
end

function ExchangeLayer:initUI()
	local _src
	local _pos
	print("self.activityType ",self.activityType)
	if self.activityType == 2 then
		_src = "res/Main/limittimehot/exchange.png"
		_pos = cc.p(-120,4)
	else
		_src = "res/Main/activity/exchange/left_bg.jpg"
		_pos = cc.p(0,-5)
	end
	local _leftBg = zc.getSprite({
		src = _src,
		pos = _pos,
		ap = cc.p(0, 0),
	})
	self:addChild(_leftBg)
	local _turnInfo = PlayerData:getActivityInfoById(16)
	local _openTime = os.date("%m" .. zc.lang("date_month") .. "%d" .. zc.lang("date_day_1"), _turnInfo.openTime )
    local _endTime = os.date("%m" .. zc.lang("date_month") .. "%d" .. zc.lang("date_day_1"), _turnInfo.endTime )
	local _text = string.format(zc.lang("tip_exchange_activity_desc"), self._tipText)
	-- _text = _text .. "\n" .. zc.lang("shijian") .. _openTime .. " ~ " .. _endTime
	local _tipLabel = zc.createRichLabel({
		text = _text,
		color = cc.c3b(111, 0, 1),
		fontSize = 16,
		pos = cc.p(93, 13),
		anchor = cc.p(0, 0),
	})
	_tipLabel:setHorizontalAlignment(cc.TEXT_ALIGNMENT_LEFT)
	_tipLabel:setVerticalAlignment(cc.VERTICAL_TEXT_ALIGNMENT_BOTTOM)
	_tipLabel:setDimensions(cc.size(220, 120))
	_leftBg:addChild(_tipLabel)

	local _contentSize = self:getContentSize()
	local tableSize 
	local tablePos
	if self.activityType == 2 then
		tableSize = cc.size(585,_contentSize.height)
		tablePos = cc.p(_leftBg:getPositionX() + _leftBg:getContentSize().width - 5, 20)
	else
		tableSize = cc.size(480, _contentSize.height)
		tablePos = cc.p(_leftBg:getContentSize().width - 20, 0)
	end
	-- tableView
	local _tabelView = zc.ZCTableView:create(tableSize)
	_tabelView:setAutoAlign( true )
    _tabelView:setBounceable( true )
    _tabelView:setInertia( true )
    _tabelView:setDirection( cc.SCROLLVIEW_DIRECTION_VERTICAL )
    _tabelView:setPosition(tablePos)
    _tabelView:setDelegate()
    _tabelView:setAnchorPoint(cc.p(0, 0))
    _tabelView:setVerticalFillOrder( cc.TABLEVIEW_FILL_TOPDOWN )

	local _cellSize = cc.size(tableSize.width, 160)
	local function cellSizeForTable( table, index )
	    return _cellSize.height, _cellSize.width
	end

	local function numberOfCellsInTableView()
	    return #self._datas
	end
	-- create cell
	local pos = {}
    local distance = 100
    local jiatouPos
    local jianTou_distance = 70
    local kuohao_distance
	if self.activityType == 2 then
		pos = {65,175}
		distance = 120
		jiatouPos = cc.p(_cellSize.width * 0.5 - 50,_cellSize.height*0.5)
		jianTou_distance = 92
		kuohao_distance = 95
	else
		distance = 100
		pos = {55,145}
		jiatouPos = cc.p(_cellSize.width * 0.5 - 10, _cellSize.height*0.5)
		jianTou_distance = 70
		kuohao_distance = 75
	end
	local function createCell( cell )
	    local _di = zc.createSprite("res/Main/activity/dekaron/cellDi.png")
        _di:setPosition(_cellSize.width*0.5, _cellSize.height*0.5)
        _di:setScaleX(_cellSize.width/_di:getContentSize().width)
        cell:addChild(_di)
        for i = 1, 2 do
        	local bg_icon = ccui.Scale9Sprite:create( cc.rect( 15, 12, 8, 8 ), "res/Main/role/common/name_bg.png")
			bg_icon:setContentSize(84,84)
			bg_icon:setPosition(i == 1 and pos[1] or pos[2], _cellSize.height*0.5)
			cell:addChild(bg_icon)

        	local _icon = zc.createIconByData({
        		data = {
        			mainType = 1,
        			type = 1,
        			id = 1,
        			num = 1,
	        	},
	        	scale = 0.6,
	        	pos = cc.p(bg_icon:getContentSize().width/2, bg_icon:getContentSize().height*0.5),
	        })
	        _icon:setTouchEndedShowTip()
	        bg_icon:addChild(_icon)
	        cell["bg_icon"..i] = bg_icon
		    cell["_icon" .. i] = _icon
        end

        -- 兑换箭头
        local _exchangeIcon = zc.createSprite("res/Main/activity/exchange/exchange_arrow.png")
    	_exchangeIcon:setPosition(jiatouPos)
        cell:addChild(_exchangeIcon)
        cell._exchangeIcon = _exchangeIcon
        -- cell:addChild(_objIcon)
       	-- 英雄碎片
       	local bg_icon = ccui.Scale9Sprite:create( cc.rect( 15, 12, 8, 8 ), "res/Main/role/common/name_bg.png")
		bg_icon:setContentSize(84,84)
		bg_icon:setPosition(_exchangeIcon:getPositionX() + jianTou_distance, _cellSize.height*0.5)
		cell:addChild(bg_icon)
		cell.bg_icon = bg_icon
		-- cell.bg
        local _objIcon = zc.createIconByData({
            data = {
	            mainType = 1,
	            type = 1,
	            id = 2,
	            num = 1,
        	},
        	scale = 0.6,
        	pos = cc.p(bg_icon:getContentSize().width/2,bg_icon:getContentSize().height/2),
        })
        bg_icon:addChild(_objIcon)

	    cell._objIcon = _objIcon

		-- 按钮上边的计数
		local _jdLab = zc.createLabel({
	    	fontSize = 20,
	    	outLine = true,
	    	pos = cc.p(_cellSize.width - kuohao_distance, _cellSize.height*0.5 + 30)
    	})
	    cell:addChild(_jdLab)
	    cell._jdLab = _jdLab
		-- 兑换按钮
		local _btn = zc.createCommomBtn({
	    	tag = 3,
	    	fontSize = 30,
	    	text = zc.lang("duihuan_2"),
	    	needEnableWhenMoving = true,
	    	needSwallow = false,
	    	scale = 0.6,
	    	pos = cc.p(_jdLab:getPositionX(), _cellSize.height*0.5 - 5),
	    	endCallback = function()
		    	if not cell._canFlag then
		    		zc.tipInfo(zc.lang("tip_exchange_unenough"))
		    		return
		    	end
	    		local comfirm =  ZCConfirmDialog:createWithParams({
	                title = zc.lang("prompt"),
	                msg = string.format(zc.lang("tip_exchange_tip"), (" " .. cell._info.num .. cell._info.name .. " ")),
	                showDi = true,
	                rightCallback = function()
	                	zc.sendHttp({
	                		apiName = "HouseShop_activityExchange",
	                		params = {id = cell._id},
	                		successCallback = function( net_data )
	                			net_data.noAnimation = true
	                			PlayerData:updataData(net_data)
	                			zc.createShowReward(net_data)
	                			self._datas[cell._idx].nums = self._datas[cell._idx].nums + 1
	                			self:sortData()
	                			self._listTab:reloadDataAndScrollToCurrentCell()
	                		end
                		})
	                end
	            })
	            comfirm._isRemoveLayout = true
	            LayerManager.addNode(comfirm, {isPop = true})
	    	end,
    	})
	    cell:addChild(_btn)
	    cell._btn = _btn
	end

	local function tableCellAtIndex(table, index)
	    local _cell = table:dequeueCell()
	    -- 创建模板
	    if _cell == nil then
	        _cell = zc.ZCTableViewCell:new()
	        _cell:setContentSize(_cellSize)
	        createCell(_cell)
	    end
	    _cell._idx = index + 1
	    local _data = self._datas[_cell._idx]
	    _cell._id = _data.id
	    local _leftTimes = _data.max - _data.nums
	    _cell._btn:setEnable(_data.limitType == 0 or _leftTimes > 0)
	    _cell._jdLab:setVisible(_leftTimes > 0)
	    local str = "(".._leftTimes.."/".._data.max..")"
	    _cell._jdLab:setString(str)

	    _cell._jdLab:setColor(_leftTimes > 0 and display.COLOR_BLUE or display.COLOR_RED)

	    _cell._icon2:setVisible(_data.item2 ~= "")
	    _cell.bg_icon2:setVisible(_data.item2 ~= "")

	    _cell.bg_icon1:setPositionX(_data.item2 == "" and distance or pos[1])
	    local x = _cell._exchangeIcon:getPositionX()
	    if self.activityType == 2 then
	    	if _data.item2 ~= "" then
	    		x = x + 30
	    	end
	    end
	    _cell._exchangeIcon:setPositionX(x)
	    _cell.bg_icon:setPositionX(x + jianTou_distance)

	    local _info = string.split(_data.item1, "|")
		zc.updateIconByData(_cell._icon1, {
			data = {
				mainType = _info[1],
				type = _info[2],
				id = _info[2],
				num = _info[3],
			},
			showCount = true
		})
        _cell._icon1:setTouchEndedShowTip()
	    local _countLabel = _cell._icon1:getChildByName("countLabel")
	    local _numHave = zc.getNumByTypeId(_info[1], _info[2])
	    local _numCost = tonumber(_info[3]) or 0
	    local _flag = _numHave >= _numCost
	    _countLabel:setColor(_flag and display.COLOR_WHITE or display.COLOR_RED)
	    
	    if _data.item2 ~= "" then
	    	_info = string.split(_data.item2, "|")
			zc.updateIconByData(_cell._icon2, {
				data = {
					mainType = _info[1],
					type = _info[2],
					id = _info[2],
					num = _info[3],
				},
				showCount = true
			})
	        _cell._icon2:setTouchEndedShowTip()
		    _countLabel = _cell._icon2:getChildByName("countLabel")
		    _numHave = zc.getNumByTypeId(_info[1], _info[2])
		    _numCost = tonumber(_info[3]) or 0
		    local _flag2 = _numHave >= _numCost
		    _countLabel:setColor(_flag2 and display.COLOR_WHITE or display.COLOR_RED)
	    	_flag = _flag and _flag2
	    end
	    _info = string.split(_data.item, "|")
		local _info = zc.updateIconByData(_cell._objIcon, {
			data = {
				mainType = _info[1],
				type = _info[2],
				id = _info[2],
				num = _info[3],
			},
			showCount = true
		})
        _cell._objIcon:setTouchEndedShowTip()
        _cell._info = _info
        _cell._canFlag = _flag

	    return _cell
	end

	_tabelView:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX)
	_tabelView:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
	_tabelView:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX)
	_tabelView:reloadData()
    self:addChild(_tabelView)
    self._listTab = _tabelView
end

return ExchangeLayer