--[[
    战斗结果页面
    唐实聪
    2016.5.12
]]
local BattleUIResultPop = class("BattleUIResultPop",function ()
    return ZCPopLayer:create({isRemoveLayout = not USE_PUSH_BATTLE})
end)

function BattleUIResultPop:create( data )
    return self.new( data )
end

function BattleUIResultPop:onEnter()
    musicManager.pauseBackgroundMusic()
end

--展示武器获取动画
function BattleUIResultPop:showGetWeapon(_call)
    --如果奖励有武器,展示
    local weaponList = {}
    for i = 1, #self._clientItems do
        local v = self._clientItems[i]
        if tonumber(v.type) and tonumber(v.type) == 3 then
            if self._battleType == BattleType.WeaponCopy then
                local _model = v.model or {}
                local _color = tonumber(_model.color) or 0
                if _color >= 3 then
                    weaponList[#weaponList+1] = v
                end
            else
                weaponList[#weaponList+1] = v
            end
        end
    end
   table.sort(weaponList, function( a, b )
        local _modeA = a.model or {}
        local _qualityA = tonumber(_modeA.quality) or 0
        local _modeB = b.model or {}
        local _qualityB = tonumber(_modeB.quality) or 0
        if _qualityA ~= _qualityB then
            return _qualityA > _qualityB
        end
        local _qualityA = tonumber(_modeA.itemId) or 0
        local _qualityB = tonumber(_modeB.itemId) or 0
        return _qualityA < _qualityB
    end)
    local function showWeapon()
        if not next(weaponList) then
            if _call then
                _call()
            end
            return
        end
        local info = PlayerData:getWeaponInfoInfoById( weaponList[1].model.id )
        table.remove(weaponList,1)
        local _pop = requires("src/pop/makeGodWeaponPop.lua"):create({info = info,onlyShow = true,isAdd=true,endCallback=function()
            showWeapon()
        end})
        self:addChild(_pop)
    end
    showWeapon()
end

--展示英雄获取动画
function BattleUIResultPop:showGetHero(_call)
    --如果奖励有武器,展示
    local _hero = nil
    for i = 1, #self._clientItems do
        local v = self._clientItems[i]
        if tonumber(v.type) and tonumber(v.type) == 2 then
            _hero = v
        end
    end
    local _currentGID = getGuideManager():getCurrentGID()
    if inArray(_currentGID, GuideGroup.BTN_BATTLE_BACK) then
        _hero = nil
    end                 
    local function showHero()
        if not _hero then
            if _call then
                _call()
            end
            return
        end
        zc.createPubShowGetHero({
            id = _hero.itemId,
            scene = self,
            callback = _call
        })
    end
    showHero()
end
function BattleUIResultPop:onExit()
    for i, v in ipairs( self._heros ) do
        local heroData = PlayerData:getGeneralInfoById( v.id )
        heroData.beforeexp = heroData.exp
        heroData.beforelevel = heroData.level
    end
    if self._effSound then
        musicManager.stopEffect(self._effSound)
    end
end

function BattleUIResultPop:ctor(data)
    self:initData( data )
    self:initUI()
    self:show(true, function()
        if not self._islevelUp then
            self:showGetHero(function()
                self:showGetWeapon(function()
                    getGuideManager():guideOver()
                    local _currentGID = getGuideManager():getCurrentGID()
                    if inArray(_currentGID, GuideGroup.BTN_BATTLE_BACK) then 
                        zc.addGuideBtn(self._backBtn)
                    end
                end)
            end)
        end
    end)
end

function BattleUIResultPop:onCleanup()
    local manager = ccs.ArmatureDataManager:getInstance()
    manager:removeArmatureFileInfo("res/Main/battle/battleresult/win/win.csb",true)
    local textureCache = cc.Director:getInstance():getTextureCache()
    textureCache:removeTextureForKey("res/animation/dzcg/dzcg.png")
    textureCache:removeTextureForKey("res/animation/failboy/failboy.png")
end
-- 构造数据
function BattleUIResultPop:initData(data)
    -- dump(data.data.data, "data.data.datawarModel-----------dump--------ad-------------" )
    -- 战斗类型
    self._battleType = data.data.battleType or BattleType.PVE
    -- 战斗场景
    self._fightScene = data.data.fightScene
    -- 战斗背景
    self._bgNode = data.data.bgNode or nil
    -- 战斗结果页需要的数据
    self._battleResultData = data.data.battleResultData or {}
    -- 战斗掉落
    self._drop = table.copy( data.data.data.items or {} )
    self._clientItems = data.data.data.clientItems or {}
    self._haveDouble = tonumber(data.data.data.isDouble) or 0

    -- 经验
    self._addExp = table.copy( data.data.data.addExp or {} )
    -- 战斗己方英雄
    self._heros = table.copy( data.data.data.heros or {} )
    -- 战报分享
    self._warKey = data.data.data.warKey
    if self._battleType == BattleType.Wushenshilian then --武神试练的warkey特殊处理，真是蛋疼
        self._warKey = data.data.warkey
    end
    -- 能否分享
    self._canShare = data.data.canShare
    -- 退出回调
    self._quit = data.quit
    -- 重播回调
    self._replay = data.replay
    -- 战斗结果
    self._batlestatus = 2
    -- 敌人名字
    self._enemyname = ""
    if data.data.data.warModels then
        local warModel = data.data.data.warModels
        self._batlestatus = warModel[#warModel][5][1] or 2
        self._enemyname = warModel[#warModel][4][1]
    else
        local warModel = data.data.data.warModel
        self._warModel = warModel
        self._batlestatus = warModel[5][1] or 2
        if warModel[4][1] == PlayerData.info.userName then
            if inArray(tonumber(self._batlestatus), {2,3,4}) then
                self._batlestatus = 0
            end
        end
        self._enemyname = warModel[4][1]
    end
    self._size = self:getContentSize()
    if self._battleType == BattleType.QunXiong then
        self._qunxiongMainId = data.data.qunxiongMainId
        self._reviveTimes = tonumber(data.data.data.reviveTimes)
    end

end
-- 创建界面
function BattleUIResultPop:initUI()
    local bg = cc.Sprite:create()
    bg:setContentSize( self._size )
    bg:setPosition( self._size.width/2, self._size.height/2 )
    self:addContent( bg )
    self._bg = bg

    if inArray(tonumber(self._batlestatus), {2,3,4}) then
        --胜利了
        self._effSound = musicManager.playEffect(zc.effect.battleWin)
        self:initSuccess()
    else
        --失败了
        self._effSound = musicManager.playEffect(zc.effect.battleLose)
        self:initFail()
    end
    self:initCommonUI()
end


---------------------胜利 begin---------------------
-- 对胜利结果进行分类处理
function BattleUIResultPop:initSuccess()

    if self._battleType == BattleType.ARENA 
      or self._battleType == BattleType.GodFight
      or self._battleType == BattleType.GrabFight then
        -- 演武榜
        self:initSuccessArena()
    elseif self._battleType == BattleType.DrillField then
        -- 校场
        self:initSuccessDrillField()
    elseif self._battleType == BattleType.MultiCopy then
        -- 多人副本
        self:initSuccessMultiCopy()
    elseif self._battleType == BattleType.CountryDartRob then
        -- 劫镖
        self:initSuccessDartUI()
    elseif self._battleType == BattleType.CountryGrabMine then
        self:initSuccessGrabMine()
    else
        -- 其他
        self:initSuccessUI()
    end

    local currentGID = getGuideManager():getCurrentGID()

    if self._battleType == BattleType.HeroCopy and currentGID ~= GuideKey.KEY_15008 then
        zc.sendHttp({
            apiName = "Hero_CopyMain",
            params = {},
            successCallback = function(data)
                PlayerData:updateHeroTrain(data)
                zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_HEROCOPY_CHANGE, data = {
                    -- chapterId = self.chapterId, 
                    data = data, 
                    -- houseIdx = self.houseIdx,
                    }
                })
            end,
        })
    end

    -- if self._battleType == BattleType.HeroCopy then
    --     if not PlayerData:getFuncGuideInfo(400) then
    --         getGuideManager():sendFuncGuideTrigger(400)
    --     end
    -- end

    if currentGID == GuideKey.KEY_15008 then
        getGuideManager():guideOver()
    end

end
-- 抢矿胜利
function BattleUIResultPop:initSuccessGrabMine()
        local curStar = 1
        if self._batlestatus then
            curStar = 5 - tonumber(self._batlestatus)
        end
        local armature = zc.createArmature({
            parentPath = "res/Main/battle/battleresult/win/",
            fileName = "win",
            actName = "star_"..curStar,
            eventCallback = function() end,
            completeCallback = function()
                self._armature:getAnimation():play("idle_"..curStar, -1, 1)
            end
        })
        armature:setPosition(cc.p(zc.width/2, zc.height/2 + 90))
        self._bg:addChild(armature)
        self._armature = armature

        --阴影
        local bg = zc.createSprite( "res/Main/battle/battleresult/battle_bg.png" )
        bg:setAnchorPoint( 0.5, 1 )
        bg:setPosition( zc.width/2, zc.height/2 + 30 )
        self._bg:addChild(bg)

        local _msg = zc.lang("qiangzhanshengli")
        if self._battleResultData and self._battleResultData.countryName then
            local _staticdata = gameData.getDataFromCacheWithPrimaryKey("mine", self._battleResultData.mineId) or {}
            local _mineName = _staticdata["name"] or ""          
            _msg = string.format(zc.lang("tips_qiangzhanzhushou_success"), tostring(self._battleResultData.countryName), tostring(_mineName))
        end

        local battleScoreText = zc.createLabel({
            text = _msg,
            fontSize = 25,
            ap = cc.p(0.5, 0.5),
            pos = cc.p(bg:getContentSize().width/2, bg:getContentSize().height/2+30),
            outLine = true,
            color = display.COLOR_GREEN,
        })
        bg:addChild(battleScoreText)

end
-- 演武榜胜利
function BattleUIResultPop:initSuccessArena()
    if self._battleResultData and self._battleResultData.arenaFlag then
        -- 战斗完
        --2 攻击方完胜, 3 攻击方大胜, 4 攻击方小胜 对应 3星 2星 1星
        local curStar = 1
        if self._batlestatus then
            curStar = 5 - tonumber(self._batlestatus)
        end
        local armature = zc.createArmature({
            parentPath = "res/Main/battle/battleresult/win/",
            fileName = "win",
            actName = "star_"..curStar,
            eventCallback = function() end,
            completeCallback = function()
                self._armature:getAnimation():play("idle_"..curStar, -1, 1)
            end
        })
        armature:setPosition(cc.p(zc.width/2, zc.height/2 + 90))
        self._bg:addChild(armature)
        self._armature = armature

        --阴影
        local bg = cc.Sprite:create( "res/Main/battle/battleresult/battle_bg.png" )
        bg:setAnchorPoint( 0.5, 1 )
        bg:setPosition( zc.width/2, zc.height/2 + 30 )
        self._bg:addChild(bg)

        -- 判断哪一天
        if self._battleType == BattleType.ARENA and inArray( self._battleResultData.shareData.type, { 1, 2, 3 }) then
            -- 预选赛
            -- 军功变化
            local battleScoreAdd = tonumber( self._battleResultData.addBattleScore ) or 0
            local battleScoreText = zc.createLabel({
                text = LANGUAGE_getReousrceNameById(zc.dataServicePoints) .. ": ",
                fontSize = 25,
                ap = cc.p(0, 0.5),
                pos = cc.p(zc.width/2 - 100, zc.height/2 - 90),
                outLine = true,
                color = display.COLOR_WHITE,
            })
            self._bg:addChild(battleScoreText)
            local battleScoreIcon = cc.Sprite:create( "res/Main/common/common_icon_battlescore.png" )
            battleScoreIcon:setPosition( battleScoreText:getContentSize().width+20, battleScoreText:getBoundingBox().height/2 )
            battleScoreText:addChild(battleScoreIcon)

            if self._haveDouble == 1 then
                battleScoreAdd = battleScoreAdd*2
            end
            local battleScoreNum = zc.createLabel({
                text = "+"..battleScoreAdd,
                fontSize = 25,
                ap = cc.p(0, 0.5),
                pos = cc.p(battleScoreText:getContentSize().width+40, battleScoreText:getBoundingBox().height/2),
                outLine = true,
                color = display.COLOR_GREEN,
            })
            battleScoreText:addChild(battleScoreNum)

            if self._haveDouble == 1 then
                local _sp = zc.createSprite("res/Main/activity/doubleAwards.png")
                _sp:setScale(0.9)
                _sp:setAnchorPoint(0, 0.5)
                _sp:setPosition(battleScoreNum:getPositionX() + battleScoreNum:getContentSize().width, battleScoreNum:getPositionY() - 5)
                battleScoreText:addChild(_sp)
            end
            -- 积分变化
            local scoreAdd = tonumber( self._battleResultData.addScore ) or 0
            local scoreText = zc.createLabel({
                text = LANGUAGE_ARENA.score .. ": ",
                fontSize = 25,
                ap = cc.p(0, 0.5),
                pos = cc.p(zc.width/2 - 100, zc.height/2 - 150),
                outLine = true,
                color = display.COLOR_WHITE,
            })
            self._bg:addChild(scoreText)
            local scoreNum = zc.createLabel({
                text = "+"..scoreAdd,
                fontSize = 25,
                ap = cc.p(0, 0.5),
                pos = cc.p(scoreText:getContentSize().width+10, scoreText:getBoundingBox().height/2),
                outLine = true,
                color = display.COLOR_GREEN,
            })
            scoreText:addChild(scoreNum)
        else
            if self._battleResultData.foodNums then
                local _foodImg = zc.createSprite("res/Main/common/common_icon_grain.png")
                _foodImg:setAnchorPoint(0, 0.5)
                _foodImg:setPosition(zc.width/2 - 100, zc.height/2 - 110)
                self._bg:addChild(_foodImg)

                local rankIcon = cc.Sprite:create( "res/Main/common/hecheng.png" )
                rankIcon:setPosition( _foodImg:getContentSize().width+15, _foodImg:getBoundingBox().height/2 )
                _foodImg:addChild(rankIcon)
                
                local _foodNumLab = zc.createLabel({
                    text = self._battleResultData.foodNums,
                    pos = cc.p(_foodImg:getContentSize().width+30, _foodImg:getBoundingBox().height/2),
                    fontSize = 25,
                    ap = cc.p(0, 0.5),
                    outLine = true,
                    color = display.COLOR_GREEN,
                })
                _foodImg:addChild(_foodNumLab)
            else
                -- 决赛
                -- 排名变化
                local rankText = zc.createLabel({
                    text = LANGUAGE_ARENA.rank .. ": "..( self._battleResultData.befRank or 0 ),
                    fontSize = 25,
                    ap = cc.p(0, 0.5),
                    pos = cc.p(zc.width/2 - 100, zc.height/2 - 110),
                    outLine = true,
                    color = display.COLOR_WHITE,
                })
                self._bg:addChild(rankText)
                local rankIcon = cc.Sprite:create( "res/Main/common/arrow_green.png" )
                rankIcon:setPosition( rankText:getContentSize().width+15, rankText:getBoundingBox().height/2 )
                rankText:addChild(rankIcon)
                local rankNum = zc.createLabel({
                    text = ( self._battleResultData.aftRank or 0 ),
                    fontSize = 25,
                    ap = cc.p(0, 0.5),
                    pos = cc.p(rankText:getContentSize().width+30, rankText:getBoundingBox().height/2),
                    outLine = true,
                    color = display.COLOR_GREEN,
                })
                rankText:addChild(rankNum)
            end
        end
    else
        -- 查看战报或者分享
        --2 攻击方完胜, 3 攻击方大胜, 4 攻击方小胜 对应 3星 2星 1星
        local curStar = 1
        if self._batlestatus then 
            curStar = 5 - tonumber(self._batlestatus)
        end
        local armature = zc.createArmature({
            parentPath = "res/Main/battle/battleresult/win/",
            fileName = "win",
            actName = "star_"..curStar,
            eventCallback = function() end,
            completeCallback = function()
                self._armature:getAnimation():play("idle_"..curStar, -1, 1)
            end
        })
        armature:setPosition(cc.p(zc.width/2, zc.height/2))
        self._bg:addChild(armature)
        self._armature = armature
    end
end
-- 校场胜利
function BattleUIResultPop:initSuccessDrillField()
    --2 攻击方完胜, 3 攻击方大胜, 4 攻击方小胜 对应 3星 2星 1星
    local curStar = 1
    if self._batlestatus then 
        curStar = 5 - tonumber(self._batlestatus)
    end
    local armature = zc.createArmature({
        parentPath = "res/Main/battle/battleresult/win/",
        fileName = "win",
        actName = "star_"..curStar,
        eventCallback = function() end,
        completeCallback = function()
            self._armature:getAnimation():play("idle_"..curStar, -1, 1)
        end
    })
    armature:setPosition(cc.p(zc.width/2, zc.height/2 + 90))
    self._bg:addChild(armature)
    self._armature = armature

    --阴影
    local bg = cc.Sprite:create( "res/Main/battle/battleresult/battle_bg.png" )
    bg:setAnchorPoint( 0.5, 1 )
    bg:setPosition( zc.width/2, zc.height/2 + 65 )
    self._bg:addChild(bg)
    --获得奖励
    local getReward = cc.Sprite:create( "res/Main/battle/battle_getreward.png" )
    getReward:setPosition( self._size.width/2, 275 )
    getReward:setScaleX( 0.1 )
    self._bg:addChild( getReward )
    getReward:runAction(
        cc.Sequence:create(
            cc.ScaleTo:create( 0.1, 1 )
        )
    )
    --线
    local line = cc.Sprite:create( "res/Main/battle/battle_line_1.png" )
    line:setPosition( self._size.width/2, 255 )
    line:setScaleX( 0.1 )
    self._bg:addChild( line )
    line:runAction(
        cc.Sequence:create(
            cc.ScaleTo:create( 0.1, 1 )
        )
    )
    
    local tip = zc.createLabel({
        text = zc.lang("tips_result_challenge_success_unlock_train_position"),
        fontSize = 20,
        outLine = true,
        ap = cc.p(0.5,0.5),
        pos = cc.p(self._size.width/2, 160),
        color = zc.COLOR_GREEN,
    })
    self._bg:addChild( tip )
end
--获取武器等级
function BattleUIResultPop:getWeaponLevel(_id)
    for i = 1, #self._clientItems do
        local v = self._clientItems[i]
        if v.type and tonumber(v.type) == zc.mainTypeWeapon then
            if tonumber(v.model.id) == tonumber(_id) then
                return zc.getWeaponLevel(_id)
            end
        end
    end
    return 0
end
-- 多人副本
function BattleUIResultPop:initSuccessMultiCopy()
    --2 攻击方完胜, 3 攻击方大胜, 4 攻击方小胜 对应 3星 2星 1星
    local curStar = 1
    if self._batlestatus then 
        curStar = 5 - tonumber(self._batlestatus)
    end
    local armature = zc.createArmature({
        parentPath = "res/Main/battle/battleresult/win/",
        fileName = "win",
        actName = "star_"..curStar,
        eventCallback = function() end,
        completeCallback = function()
            self._armature:getAnimation():play("idle_"..curStar, -1, 1)
        end
    })
    armature:setPosition(cc.p(zc.width/2, zc.height/2 + 90))
    self._bg:addChild(armature)
    self._armature = armature

    if #self._drop == 0 and #self._heros == 0 then
        -- 如果没有英雄和获得物品，胜利下移
        armature:setPosition( zc.width/2, zc.height/2 + 20 )
        return
    end

    -- -- 掉落装备
    local dropItemData = self._drop or {}

    --阴影
    local bg = cc.Sprite:create( "res/Main/battle/battleresult/battle_bg.png" )
    bg:setAnchorPoint( 0.5, 1 )
    bg:setPosition( zc.width/2, zc.height/2 + 65 )
    self._bg:addChild(bg)

    -- item
    local itemsNum = #dropItemData
    -- 滑动限制
    local limit = 8

    if itemsNum >= limit then
        -- 太多，可滑动
        local itemScrollview = zc.createScrollview({
            pos = cc.p( (self._size.width - 75*(limit - 0.5) )/2, 200 ),
            size = cc.size( 75*(limit - 0.5), 100 ),
            innerSize = cc.size( 75*itemsNum, 100 ),
            dir = ccui.ScrollViewDir.horizontal,
            bounceEnable = true,
        })
        self._bg:addChild( itemScrollview )
        for i, v in ipairs( dropItemData ) do
            local item = zc.createIconByData({
                data = {
                    mainType = v.itemType,
                    type = v.itemId, 
                    id = v.itemId,
                    num = v.changeNum,
                }, 
                showDetailPop = true,
                pos = cc.p( 75*( i - 0.5 ), 40 ), 
                level = tonumber(v.itemType) == zc.mainTypeWeapon and zc.getLevelTipShow()..zc.getWeaponLevel(v.model.id) or nil,
            })
            showLevel = tonumber(v.itemType) == zc.mainTypeWeapon and true or false
            item:setScale( 0.01 )
            itemScrollview:addChild( item )
            item:runAction(
                cc.Sequence:create(
                    cc.DelayTime:create( 0.1*( i - 1 ) ),
                    cc.ScaleTo:create( 0.1, 1 ),
                    cc.ScaleTo:create( 0.1, 0.6 )
                )
            )
        end
    else
        -- 数量少直接创建
        for i, v in ipairs( dropItemData ) do
            local item = zc.createIconByData({
                data = {
                    mainType = v.itemType,
                    type = v.itemId, 
                    id = v.itemId,
                    num = v.changeNum,
                    level = tonumber(v.itemType) == zc.mainTypeWeapon and zc.getLevelTipShow()..zc.getWeaponLevel(v.model.id) or nil,
                }, 
                showLevel = tonumber(v.itemType) == zc.mainTypeWeapon and true or false,
                showDetailPop = true,
                pos = cc.p( self._size.width/2 - ( ( itemsNum + 1)/2 - i )*75, 200 ), 
            })
            item:setScale( 0.01 )
            self._bg:addChild( item )
            item:runAction(
                cc.Sequence:create(
                    cc.DelayTime:create( 0.1*( i - 1 ) ),
                    cc.ScaleTo:create( 0.1, 1 ),
                    cc.ScaleTo:create( 0.1, 0.6 )
                )
            )
        end
    end
end
-- 劫镖胜利
function BattleUIResultPop:initSuccessDartUI()
    --2 攻击方完胜, 3 攻击方大胜, 4 攻击方小胜 对应 3星 2星 1星
    local curStar = 1
    if self._batlestatus then 
        curStar = 5 - tonumber(self._batlestatus)
    end
    local armature = zc.createArmature({
        parentPath = "res/Main/battle/battleresult/win/",
        fileName = "win",
        actName = "star_"..curStar,
        eventCallback = function() end,
        completeCallback = function()
            self._armature:getAnimation():play("idle_"..curStar, -1, 1)
        end
    })
    armature:setPosition(zc.width/2, zc.height/2 + 20)
    self._bg:addChild(armature)
    self._armature = armature
end
-- 其他胜利
function BattleUIResultPop:initSuccessUI()
    --2 攻击方完胜, 3 攻击方大胜, 4 攻击方小胜 对应 3星 2星 1星
    local curStar = 1
    if self._batlestatus then 
        curStar = 5 - tonumber(self._batlestatus)
    end
    local armature = zc.createArmature({
        parentPath = "res/Main/battle/battleresult/win/",
        fileName = "win",
        actName = "star_"..curStar,
        eventCallback = function() end,
        completeCallback = function()
            self._armature:getAnimation():play("idle_"..curStar, -1, 1)
        end
    })
    armature:setPosition(cc.p(zc.width/2, zc.height/2 + 90))
    self._bg:addChild(armature)
    self._armature = armature

    if #self._drop == 0 and #self._heros == 0 then
        -- 如果没有英雄和获得物品，胜利下移
        armature:setPosition( zc.width/2, zc.height/2 + 20 )
        return
    end

    -- -- 掉落装备
    local dropItemData = self._drop or {}

    --test
    -- dropItemData[#dropItemData+1] = {
    --     ["changeNum"] = 1,
    --     ["itemId"]    = 12,
    --     ["itemType"]  = 1,
    -- }
    --清理数据（处理掉名将传体力）
    for k, v in pairs(dropItemData) do
        if v and v.itemType and v.itemId then
            if tonumber(v.itemType) == zc.mainTypeResource and tonumber(v.itemId) == zc.dataTypeCaptainEnergy then
                table.remove(dropItemData,k)
                break
            end
        end
    end

    --阴影
    local bg = cc.Sprite:create( "res/Main/battle/battleresult/battle_bg.png" )
    bg:setAnchorPoint( 0.5, 1 )
    bg:setPosition( zc.width/2, zc.height/2 + 65 )
    self._bg:addChild(bg)
    --获得奖励
    local getReward = cc.Sprite:create( "res/Main/battle/battle_getreward.png" )
    getReward:setPosition( self._size.width/2, 215 )
    getReward:setScaleX( 0.1 )
    self._bg:addChild( getReward )
    getReward:runAction(
        cc.Sequence:create(
            cc.ScaleTo:create( 0.1, 1 )
        )
    )
    --线
    local line = cc.Sprite:create( "res/Main/battle/battle_line_1.png" )
    line:setPosition( self._size.width/2, 195 )
    line:setScaleX( 0.1 )
    self._bg:addChild( line )
    line:runAction(
        cc.Sequence:create(
            cc.ScaleTo:create( 0.1, 1 )
        )
    )

    -- 武将
    -- 整理数据
    local myHeros = self._heros
    local heroData = {}
    for i, v in ipairs( PlayerData:getGeneralInfo() ) do
        heroData[tostring( v.id )] = v
    end
    -- 创建icon
    self._islevelUp = false --是否升级
    for i, v in ipairs( myHeros ) do
        local _id = tonumber( v.id ) or 0
        local data = heroData[tostring( v.id )] or {}
        -- dump( data, "data" )
        v.beforeexp = tonumber( data.beforeexp ) or 0
        v.beforelevel = tonumber( data.beforelevel ) or 0
        v.level = tonumber( v.level ) or 0
        v.iconId = data.iconId or 1
        -- dump( v, "v" )

        local posx = self._size.width/2 + ( #myHeros/2 + 0.5 - i )*100
        local hero = zc.createIconByData({
            data = {
                mainType = zc.mainTypeSoldier,
                type = data.heroId, 
                id = data.heroId,
                level = zc.getLevelTipShow()..v.level,
                reincarnate = data.reincarnate,
            },
            quality = data.quality or 1,
            showLevel = true,
            showDetailPop = false,
            pos = cc.p( posx, 322 ), 
        })
        hero:setScale( 0.72 )
        self._bg:addChild( hero )

        local _expData = self._addExp[_id] or {}

        --经验条
        local expBg = cc.Sprite:create( "res/Main/battle/battle_pro2_1.png" )
        expBg:setPosition( posx, 272 )
        self._bg:addChild( expBg )
        local expBar = cc.ProgressTimer:create( cc.Sprite:create( "res/Main/battle/battle_pro2_2.png" ) )
        expBar:setType( cc.PROGRESS_TIMER_TYPE_BAR )
        expBar:setMidpoint( cc.p( 0, 0.5 ) )
        expBar:setBarChangeRate( cc.p( 1, 0 ) )
        expBar:setPosition( expBg:getContentSize().width/2, expBg:getContentSize().height/2 )
        expBg:addChild( expBar )

        --进度
        local expPct = tonumber( v.beforeexp ) / tonumber( v.expLimit ) * 100
        expBar:setPercentage( expPct )
        local expAddPct = tonumber( v.exp ) / tonumber( v.expLimit ) * 100
        local expText = "Exp+"..tostring( _expData.changeNum or 0 )
        if APP_REVIEW then
            expText = zc.lang("exp") .. "+"..tostring( _expData.changeNum or 0 )
        end
        if _expData and _expData.levelUp == 1 then
            self._islevelUp = true
            -- 升级
            local _mainRole = tonumber( PlayerData.info.heroId ) == tonumber( v.id )
            -- 经验条
            expBar:runAction(
                cc.Sequence:create(
                    cc.ProgressTo:create( 0.5, 100 ),
                    cc.DelayTime:create( 0.5 ),
                    cc.ProgressTo:create( 0, 0 ),
                    cc.ProgressTo:create( 0.5, expAddPct )
                )
            )
            -- 添加屏蔽
            local touchLayer = zc.createPushButton({
                touchSize = self:getContentSize(),
                pos = cc.p( self:getContentSize().width/2, self:getContentSize().height/2 ),
                needSwallow = true,
                endCallback = function()
                end
            })
            self:addChild( touchLayer, 110 )
            -- 动画
            musicManager.playEffect( zc.effect.levelUp )
            local armature = zc.createArmature({
                parentPath = "res/animation/eff_leverUp/",
                fileName = "eff_leverUp",
                autoRemove = true,
                actName = "eff_levelUp",
                completeCallback = function()
                    touchLayer:removeFromParent()
                    if _mainRole then
                         --新手引导
                        -- 弹窗
                        -- dump(v, "createLevelUpPop")
                        self:showGetHero(function()
                            self:showGetWeapon(function() 
                                local _currentGID = getGuideManager():getCurrentGID()
                                if inArray(_currentGID, GuideGroup.BTN_BATTLE_BACK) then
                                    getGuideManager():guideOver()
                                    zc.addGuideBtn(self._backBtn)
                                    return
                                end
                                zc.createLevelUpPop()
                            end)
                        end)
                    end
                end,
                eventCallback = function()
                end
            })
            armature:setAnchorPoint( 0.5, 0.5 )
            armature:setPosition( hero:getPositionX(), hero:getPositionY() + 40 )
            self._bg:addChild( armature, 1 )
        else
            -- 没升级
            expBar:runAction(
                cc.ProgressTo:create( 0.5, expAddPct )
            )
        end
        -- 获得经验值
        local expLabel = zc.createLabel({
            text = expText,
            fontSize = 20,
            outLine = true,
            pixel = 1,
            ap = cc.p(0.5,0.5),
            pos = cc.p(posx, 245),
        })
        self._bg:addChild( expLabel )
    end

    -- item
    local itemsNum = #dropItemData

    table.sort(dropItemData, function( a, b )
        local _mainTypeA = tonumber(a.itemType) or 0
        local _mainTypeB = tonumber(b.itemType) or 0
        local _idA = tonumber(a.itemId) or 0
        local _idB = tonumber(b.itemId) or 0
        if _mainTypeA ~= _mainTypeB then
            return _mainTypeA > _mainTypeB
        elseif _mainTypeA == 3 then
            local _dbA = gameData.getDataFromCacheWithPrimaryKey("weapon", a.itemId)
            local _dbB = gameData.getDataFromCacheWithPrimaryKey("weapon", b.itemId)
            local _qualityA = tonumber(_dbA.quality) or 0
            local _qualityB = tonumber(_dbB.quality) or 0
            if _qualityA ~= _qualityB then
                return _qualityA > _qualityB
            end
            return _idA < _idB
        elseif _mainTypeA == 4 then
            local _dbA = gameData.getDataFromCacheWithPrimaryKey("item", a.itemId)
            local _dbB = gameData.getDataFromCacheWithPrimaryKey("item", b.itemId)
            local _qualityA = tonumber(_dbA.quality) or 0
            local _qualityB = tonumber(_dbB.quality) or 0
            if _qualityA ~= _qualityB then
                return _qualityA > _qualityB
            end
            return _idA < _idB
        end
        return false
    end)


    -- 滑动限制
    local limit = 8
    
    local _bei = PlayerData:checkActivityOpenState(20) and 2 or 1
    if itemsNum >= limit then
        -- 太多，可滑动
        local itemScrollview = zc.createScrollview({
            pos = cc.p( (self._size.width - 75*(limit - 0.5) )/2, 90 ),
            size = cc.size( 75*(limit - 0.5), 100 ),
            innerSize = cc.size( 75*itemsNum, 100 ),
            dir = ccui.ScrollViewDir.horizontal,
            bounceEnable = true,
        })
        self._bg:addChild( itemScrollview )

        for i, v in ipairs( dropItemData ) do
            local _itemType = tonumber(v.itemType) or 1
            local _num = tonumber(v.changeNum) or 0
            local _flag_ = false
            local _bei_ = 1
            if self._battleType == BattleType.PVE and self._haveDouble == 1 and _itemType == zc.mainTypeProp then
                _bei_ = _bei
                _num = _num/_bei_
            end
            local item = zc.createIconByData({
                data = {
                    mainType = v.itemType,
                    type = v.itemId, 
                    id = v.itemId,
                    num = _num,
                    level = _itemType == zc.mainTypeWeapon and zc.getLevelTipShow()..zc.getWeaponLevel(v.model.id) or nil,
                },
                showBei = _bei_,
                showLevel = _itemType == zc.mainTypeWeapon and true or false,
                showDetailPop = true,
                pos = cc.p( 75*( i - 0.5 ), 40 ), 
            })
            item:setScale( 0.01 )
            itemScrollview:addChild( item )
            item:runAction(
                cc.Sequence:create(
                    cc.DelayTime:create( 0.1*( i - 1 ) ),
                    cc.ScaleTo:create( 0.1, 1 ),
                    cc.ScaleTo:create( 0.1, 0.6 )
                )
            )
        end
    else
        -- 数量少直接创建
        for i, v in ipairs( dropItemData ) do
            local _itemType = tonumber(v.itemType) or 1
            local _num = tonumber(v.changeNum) or 0
            local _flag_ = false
            local _bei_ = 1
            if self._battleType == BattleType.PVE and self._haveDouble == 1 and _itemType == zc.mainTypeProp then
                _bei_ = _bei
                _num = _num/_bei_
            end
            local item = zc.createIconByData({
                data = {
                    mainType = v.itemType,
                    type = v.itemId, 
                    id = v.itemId,
                    num = _num,
                    level = _itemType == zc.mainTypeWeapon and zc.getLevelTipShow()..zc.getWeaponLevel(v.model.id) or nil,
                }, 
                showBei = _bei_,
                showLevel = _itemType == zc.mainTypeWeapon and true or false,
                showDetailPop = true,
                pos = cc.p( self._size.width/2 - ( ( itemsNum + 1)/2 - i )*75, 135 ), 
            })
            item:setScale( 0.01 )
            self._bg:addChild( item )
            item:runAction(
                cc.Sequence:create(
                    cc.DelayTime:create( 0.1*( i - 1 ) ),
                    cc.ScaleTo:create( 0.1, 1 ),
                    cc.ScaleTo:create( 0.1, 0.6 )
                )
            )
        end
    end
end
---------------------胜利 end---------------------




---------------------失败 begin---------------------
-- 对失败结果进行分类处理
function BattleUIResultPop:initFail()
    local currentGID = getGuideManager():getCurrentGID()
    
    if self._battleType == BattleType.QunXiong then
        self:initQunXiongFailUI()
    elseif self._battleType == BattleType.MultyCopy then
        self:initFailMultiCopy()
    else
        self:initFailUI()
    end

    if currentGID == GuideKey.KEY_15008 then
        getGuideManager():setFuncGuideOver()
    end

end
-- 群雄战斗失败处理
function BattleUIResultPop:initQunXiongFailUI()
    local qunxiongbg =  zc.getSprite({
        src = "res/Main/battle/battleresult/qunxiongLose/lose_bg.png",
        ap = cc.p(0.5, 0.5),
        pos = cc.p(zc.width/2, zc.height/2),
    })
    self._bg:addChild(qunxiongbg)
    local qunxiongSize = qunxiongbg:getContentSize()
    local titleSp = zc.createSprite("res/Main/battle/battleresult/qunxiongLose/lose_title.png")
    titleSp:setAnchorPoint(0.5, 0.5)
    titleSp:setPosition(qunxiongbg:getContentSize().width/2, qunxiongbg:getContentSize().height)
    qunxiongbg:addChild(titleSp)
    local tipLab = zc.createLabel({
        text = zc.lang("tips_resurgence"),
        outLine = true,
        fontSize = 24,
        ap = cc.p(0.5, 0.5),
        pos = cc.p(qunxiongSize.width/2, qunxiongSize.height-90),
        color = display.COLOR_YELLOW,
        color2 = display.COLOR_BLACK,
        align = kCCTextAlignmentCenter,
        pixel = 1.3
    })
    qunxiongbg:addChild(tipLab)
    local close = zc.createBackButton({
        pos = cc.p(qunxiongbg:getContentSize().width-105, qunxiongbg:getContentSize().height),
        listener = function () 
            cc.Director:getInstance():getScheduler():setTimeScale(1)
            self:colseBattle()
        end,
    })
    qunxiongbg:addChild(close)
    local captain_revive_buff = gameData.getAllDataWithNoClone( "captain_revive_buff" )
    local _num = table.nums(captain_revive_buff)
    local distance = 226
    local pos = zc.sortFromMiddle( cc.p(qunxiongSize.width/2,qunxiongSize.height/2), _num, distance )
    local iconPath = {
        [1] = "res/Main/role/fetter/icon/1_3.jpg",
        [2] = "res/Main/role/fetter/icon/3_3.jpg",
        [3] = "res/Main/role/fetter/icon/4_3.jpg",
        [4] = "res/Main/role/fetter/icon/5_3.jpg",
    }
    for i = 1, _num do
        local _buffData = gameData.getDataFromCacheWithPrimaryKey("captain_revive_buff", i)
        local effectBg = zc.createSprite("res/Main/battle/battleresult/qunxiongLose/lost_item.png")
        effectBg:setAnchorPoint(0.5, 0.5)
        effectBg:setPosition(pos[i])
        qunxiongbg:addChild(effectBg)
        local iconBg = cc.Sprite:create( "res/Main/role/fetter/iconBg.png" )
        iconBg:setAnchorPoint(0.5, 0.5)
        iconBg:setPosition(effectBg:getContentSize().width/2, 116)
        effectBg:addChild(iconBg)
        local icon = zc.createSprite(iconPath[i])
        icon:setAnchorPoint(0.5, 0.5)
        icon:setPosition(iconBg:getContentSize().width/2, iconBg:getContentSize().height/2)
        iconBg:addChild(icon)
        local effectLab = zc.createLabel({
            text = LANGUAGE_getAttributeTextById(_buffData["buffType"]),
            outLine = true,
            fontSize = 20,
            ap = cc.p(0.5, 0.5),
            pos = cc.p(0, 39),
            color = display.COLOR_WHITE,
            color2 = display.COLOR_BLACK,
            align = kCCTextAlignmentCenter,
            pixel = 1.3
        })
        effectBg:addChild(effectLab)
        local effectNum = zc.createLabel({
            text = "+"..zc.getAttributeNumById(_buffData["buffType"],_buffData["buffValue"]),
            outLine = true,
            fontSize = 20,
            ap = cc.p(0, 0.5),
            pos = cc.p(0, effectLab:getPositionY()),
            color = display.COLOR_WHITE,
            color2 = display.COLOR_BLACK,
            align = kCCTextAlignmentCenter,
            pixel = 1.3
        })
        effectBg:addChild(effectNum)
        effectLab:setPositionX(effectBg:getContentSize().width/2-effectNum:getContentSize().width/2)
        effectNum:setPositionX(effectLab:getPositionX()+effectLab:getContentSize().width/2)
        local selectItem = zc.createSprite("res/Main/battle/battleresult/qunxiongLose/lose_select.png")
        selectItem:setAnchorPoint(0.5, 0.5)
        selectItem:setPosition(pos[i])
        qunxiongbg:addChild(selectItem)
        selectItem:setVisible(false)
        if i == 1 then
           selectItem:setVisible(true)
           self._selectBuffid =  _buffData["id"]
           self._selectItem = selectItem
        end
        local selectBtn = zc.createPushButton({
            touchSize = cc.size(150,190),
            needSwallow = false,
            endCallback = function()
                if self._selectItem then
                    self._selectItem:setVisible(false)
                end
                selectItem:setVisible(true)
                self._selectItem = selectItem
                self._selectBuffid =  _buffData["id"]
            end,
            anchor = cc.p(0.5, 0.5),
            pos = cc.p(pos[i])
        })
        qunxiongbg:addChild(selectBtn)
    end
    local reviveBtn = zc.createCommomBtn({
        tag = 1,
        text = zc.lang("resurgence2"),
        needSwallow = true,
        endCallback = function()
            zc.sendHttp({
                apiName = "Captain_revive",
                params = {id=self._qunxiongMainId,buff=self._selectBuffid},
                successCallback = function (data)
                    data.items = PlayerData:getShowIconDatas(data)
                    
                    data.noAnimation = true
                    PlayerData:updataData(data)
                    local _data = {data = data}
                    _data.qunxiongMainId = self._qunxiongMainId
                    _data.battleType = self._battleType
                    _data.canShare = true
                    _data.fightScene = self._fightScene
                    _data.bgNode = self._bgNode
                    _data.bgNode:retain()
                    _data.bgNode:removeFromParentAndCleanup(false)
                    _data.__isQunXiongRevive = true
                    -- LayerManager.removeLayout(true,nil,false)
                    -- LayerManager.removeLayout(nil,nil,false)
                    local battle
                    xpcall(function ( ... )
                        battle = zc.createBattle({data = _data})
                        _data.bgNode:release()
                    end, function ( msg )
                        _data.bgNode:release()
                        zc.showErrorDialog(msg)
                    end)
                    battle:play()
                end,
            })
        end,
        anchor = cc.p(0.5, 0.5),
        pos = cc.p(qunxiongSize.width/2, 61)
    })
    qunxiongbg:addChild(reviveBtn)

    local consume_price = gameData.getDataFromCache("consume_price", {type=35} )
    local priceId = tonumber(self._reviveTimes) + 1
    if priceId > #consume_price then
        priceId = #consume_price
    end
    local priceImg = zc.createSprite("res/Main/common/common_icon_gold.png")
    priceImg:setAnchorPoint(0.5, 0.5)
    priceImg:setPosition(reviveBtn:getPositionX()-130, reviveBtn:getPositionY() )
    qunxiongbg:addChild(priceImg)
    local price = zc.createLabel({
        text = consume_price[priceId].price,
        outLine = true,
        fontSize = 22,
        ap = cc.p(0, 0.5),
        pos = cc.p(priceImg:getPositionX()+priceImg:getContentSize().width/2, priceImg:getPositionY()),
        color = display.COLOR_WHITE,
        color2 = display.COLOR_BLACK,
        align = kCCTextAlignmentCenter,
        pixel = 1.3
    })
    qunxiongbg:addChild(price)
end
-- 多人副本失败
function BattleUIResultPop:initFailMultiCopy()
    local bg =  zc.getSprite({
        src = "res/Main/battle/battleresult/battle_bg.png",
        ap = cc.p(0.5, 0),
        pos = cc.p(zc.width/2, -10),
    })
    self._bg:addChild(bg)

    local failboy = zc.getSpine("failboy")
    failboy:playAction("idle",true)
    failboy:setPosition( bg:getContentSize().width/2 + 100, bg:getContentSize().height + 40)
    self._bg:addChild( failboy )

    --battle_zi
    local zi =  zc.getSprite({
        src = "res/Main/battle/battleresult/battle_zi.png",
        pos = cc.p(bg:getContentSize().width/2, bg:getContentSize().height - 30),
    })
    bg:addChild(zi)
    local line =  zc.getSprite({
        src = "res/Main/battle/battleresult/battle_line.png",
        pos = cc.p(bg:getContentSize().width/2, bg:getContentSize().height - 60),
    })
    bg:addChild(line)
    local btnH = 200
    local touchScale = 0.9

    --新手引导 处理失败
    getGuideManager():guideOver()
    getGuideManager():setNextGID(GuideKey.KEY_OVER) --结束引导
end
-- 劫镖失败
function BattleUIResultPop:initFailDartUI()
    local failboy = zc.getSpine("failboy")
    failboy:playAction("idle",true)
    failboy:setPosition(zc.width/2, zc.height/2 - 100)
    self._bg:addChild( failboy )
end
function BattleUIResultPop:initFailUI()
    local bg =  zc.getSprite({
        src = "res/Main/battle/battleresult/battle_bg.png",
        ap = cc.p(0.5, 0),
        pos = cc.p(zc.width/2, -10),
    })
    self._bg:addChild(bg)

    local failboy = zc.getSpine("failboy")
    failboy:playAction("idle",true)
    failboy:setPosition( bg:getContentSize().width/2 + 100, bg:getContentSize().height + 40)
    self._bg:addChild( failboy )

    --battle_zi
    local zi =  zc.getSprite({
        src = "res/Main/battle/battleresult/battle_zi.png",
        pos = cc.p(bg:getContentSize().width/2, bg:getContentSize().height - 30),
    })
    bg:addChild(zi)
    local line =  zc.getSprite({
        src = "res/Main/battle/battleresult/battle_line.png",
        pos = cc.p(bg:getContentSize().width/2, bg:getContentSize().height - 60),
    })
    bg:addChild(line)
    local btnH = 200
    local touchScale = 0.9
    --合理布阵
    local buzhenButton = zc.createPushButton({
        normalFile = "res/Main/common/common_icon_buzhen.png",
        pos = cc.p(bg:getContentSize().width/2 - 70*3, btnH), 
        endCallback = function () 
            LayerManager.backToMainCity()
            zc.createBuzhenLayer()
        end,
        scale = 0.7,
        touchScale = touchScale
    })
    local _label_buzhen = zc.createLabel({
        text = zc.lang("helibuzhen"),
        fontSize = 30,
        outLine = true,
        pixel = 3,
        ap = cc.p(0.5,0),
        pos = cc.p(buzhenButton:getContentSize().width/2, -25),
    })
    buzhenButton:addChild(_label_buzhen)
    bg:addChild(buzhenButton)
    
    --打造兵器
    local weaponButton = zc.createPushButton({
        normalFile = "res/Main/common/common_icon_bingqipu.png",
        pos = cc.p(bg:getContentSize().width/2 - 70, btnH), 
        endCallback = function () 
            LayerManager.backToMainCity()
            local mainCity = zc.getScene("mainCity")
            if mainCity and mainCity.houseList then
                for k,v in pairs(mainCity.houseList) do
                    local _houseId = v:getHouseId()
                    if tonumber(_houseId) == 11 then
                        zc.showEntityTouchPop(v)
                        break
                    end
                end
            end
        end,
        scale = 0.7,
        touchScale = touchScale
    })
    local _label_weapon = zc.createLabel({
        text = zc.lang("strength_weapon"),
        fontSize = 30,
        outLine = true,
        pixel = 3,
        ap = cc.p(0.5,0),
        pos = cc.p(weaponButton:getContentSize().width/2, -25),
    })
    weaponButton:addChild(_label_weapon)
    bg:addChild(weaponButton)
    --装备强化
    local weaponStrongBtn = zc.createPushButton({
        normalFile = "res/Main/common/common_icon_zhuangbei.png",
        pos = cc.p(bg:getContentSize().width/2 + 70, btnH), 
        endCallback = function ()
            LayerManager.backToMainCity()
            local _upHero = PlayerData:getNowFormationFiles()
            local _formationInfo = PlayerData:getFormationsInfo() or {}
            for i, v in pairs( _formationInfo ) do
                if v.status == 1 then
                    for j = 1, 9 do
                        local _id = tonumber( v["location"..j] ) or 0
                        if _id ~= 0 then
                            _upHero[_id] = true
                        end
                    end
                end
            end
            local _heroList = PlayerData:getGeneralInfo()
            local _mainHeroData = {}
            local _otherHeroData = {}
            for i, v in ipairs( _heroList ) do
                local _id = tonumber( v.id ) or 0
                if _id == tonumber( PlayerData.info.heroId ) then
                    -- 主角
                    _mainHeroData[#_mainHeroData + 1] = v
                elseif _upHero[_id] then
                    -- 武将
                    _otherHeroData[#_otherHeroData + 1] = v
                end
            end
            -- 装备强化
            local _heroData = { _mainHeroData, _otherHeroData }
            local _heroId = 0
            local _position = 0
            local _status
            local _params 
            _status, _heroId, _position = zc.getEquipRedDotStatus( _heroData[1] )
            if _status then
                _params = {id = _heroId, position = _position}
            else
                _status, _heroId, _position = zc.getEquipRedDotStatus( _heroData[2] )
                _heroId = _heroData[2][1] or {}
                _heroId = _heroId.id
                _params = {id = _heroId, position = 1}
            end
            zc.gotoFunction( 36, _params, false )
        end,
        scale = 0.7,
        touchScale = touchScale
    })
    local _label_equip_strong = zc.createLabel({
        text = zc.lang("equip_strength"),
        fontSize = 30,
        outLine = true,
        pixel = 3,
        ap = cc.p(0.5,0),
        pos = cc.p(weaponStrongBtn:getContentSize().width/2, -25),
    })
    weaponStrongBtn:addChild(_label_equip_strong)
    bg:addChild(weaponStrongBtn)
    --我要变强
    local strongBtn = zc.createPushButton({
        normalFile = "res/Main/common/common_icon_bianqiang.png",
        pos = cc.p(bg:getContentSize().width/2 + 70*3, btnH), 
        endCallback = function () 
            LayerManager.backToMainCity()
            zc.createStrongerLayer()
        end,
        scale = 0.7,
        touchScale = touchScale
    })
    local _label_strong = zc.createLabel({
        text = zc.lang("i_want_to_strong"),
        fontSize = 30,
        outLine = true,
        pixel = 3,
        ap = cc.p(0.5,0),
        pos = cc.p(strongBtn:getContentSize().width/2, -25),
    })
    strongBtn:addChild(_label_strong)
    bg:addChild(strongBtn)

    --新手引导 处理失败
    getGuideManager():guideOver()
    getGuideManager():setNextGID(GuideKey.KEY_OVER) --结束引导
end
---------------------失败 end---------------------



---------------------通用 begin---------------------
-- 通用按钮
function BattleUIResultPop:initCommonUI()
    ----------------------------------------按钮
    --返回
    local backBtn = zc.createPushButton({
        normalFile = "res/Main/battle/battle_fh_u.png",
        selectedFile = "res/Main/battle/battle_fh_d.png",
        needSwallow = false,
        endCallback = function()
            --新手引导
            local _currentGID = getGuideManager():getCurrentGID()
            if inArray(_currentGID, GuideGroup.BTN_BATTLE_BACK) then
                getGuideManager():guideOver()
                getGuideManager():setNextGID(_currentGID)
            end
            cc.Director:getInstance():getScheduler():setTimeScale(1)
            self:colseBattle()
        end,
        pos = cc.p(zc.width - 80, 250),
    })
    self._bg:addChild(backBtn)
    self._backBtn = backBtn
    --重播
    local replayBtn = zc.createPushButton({
        normalFile = "res/Main/battle/battle_cb_u.png",
        selectedFile = "res/Main/battle/battle_cb_d.png",
        needSwallow = false,
        endCallback = function()
            musicManager.resumBackgroundMusic()
            self:replayBattle() 
        end,
        pos = cc.p(zc.width - 80, 450),
    })
    self._bg:addChild(replayBtn)
    self._replayBtn = replayBtn
    --分享
    local btn_normal = cc.Sprite:create( "res/Main/battle/battle_fx_u.png" )
    local btn_selected = cc.Sprite:create( "res/Main/battle/battle_fx_d.png" )
    local btn_disable = cc.Sprite:create( "res/Main/battle/battle_fx_u.png" )
    zc.setGray( btn_disable )
    local shareBtn = zc.createPushButton({
        normalNode = btn_normal,
        selectedNode = btn_selected,
        disableNode = btn_disable,
        pos = cc.p(zc.width - 80, 350),
        endCallback = function ()
            if APP_SERVER == 0 or APP_ENV == "dev" then
                zc.SaveTable("warModel", self._warModel)
            end
            local _text = nil
            if self._battleType == BattleType.ARENA then
                -- 演武榜
                if self._battleResultData and self._battleResultData.shareData then
                    -- 只有战斗结束才能分享，演武榜战报里分享的不是实时的
                    local shareData = {}
                    local _pText = ""
                    self._battleResultData.shareData.warKey = self._warKey
                    if inArray(tonumber(self._batlestatus), {2,3,4}) then
                        -- 胜利
                        if inArray( self._battleResultData.shareData.type, { 1, 2, 3 }) then
                            -- 前六天
                            _pText = LANGUAGE_ARENA_SHAREDATA( 3, self._battleResultData.shareData )
                        else
                            -- 最后一天
                            _pText = LANGUAGE_ARENA_SHAREDATA( 4, self._battleResultData.shareData )
                        end
                    else
                        -- 失败
                        _pText = LANGUAGE_ARENA_SHAREDATA( 5, self._battleResultData.shareData )
                    end
                    _text = ""
                    for i=2, #_pText do
                        if _pText[i].name then
                            _text = _text .. _pText[i].name
                        elseif _pText[i].text then
                            _text = _text .. _pText[i].text
                        elseif _pText[i].key then
                            _text = _text .. "{key=" .. _pText[i].key .. "}"
                        end
                    end
                end
            elseif self._battleType == BattleType.KaHei then
                if inArray(tonumber(self._batlestatus), {2,3,4}) then
                    _text = LANGUAGE_BATTLE_RESULT_SHARE(self._enemyname, self._warKey, 1)
                else
                    _text = LANGUAGE_BATTLE_RESULT_SHARE(self._enemyname, self._warKey, 2)
                end
            elseif self._battleType == BattleType.GodFight then
                if inArray(tonumber(self._batlestatus), {2,3,4}) then
                    _text = LANGUAGE_BATTLE_RESULT_SHARE(self._enemyname, self._warKey, 5)
                else
                    _text = LANGUAGE_BATTLE_RESULT_SHARE(self._enemyname, self._warKey, 6)
                end
            else
                if inArray(tonumber(self._batlestatus), {2,3,4}) then
                    _text = LANGUAGE_BATTLE_RESULT_SHARE(self._enemyname, self._warKey, 3)
                else
                    _text = LANGUAGE_BATTLE_RESULT_SHARE(self._enemyname, self._warKey, 4)
                end
            end
            if _text then
                self._canShare = false
                getNetManager():getRequestCenter():sendBattleFieldChatData(_text)
                zc.tipInfo(zc.lang("tips_battle_field_success"))
                self._shareBtn:setEnable(false)
            end
        end
    })
    self._bg:addChild(shareBtn)
    self._shareBtn = shareBtn
    if not self._canShare then
        shareBtn:setEnable(false)
    end
    -- 演武榜只有战斗结束和观看战报回放的时候可以分享
    if self._battleType == BattleType.ARENA then
        if not self._battleResultData or not self._battleResultData.shareData then
            shareBtn:setEnable(false)
        end 
    elseif self._battleType == BattleType.QunXiong then
        if not inArray(tonumber(self._batlestatus), {2,3,4}) then
            self._backBtn:setVisible(false)
            self._replayBtn:setVisible(false)
            self._shareBtn:setVisible(false)        
        end
    end
end

--重播
function BattleUIResultPop:replayBattle()
    if self._replay then
        self._replay( self._canShare )
    end
    self:hide({noAction = true})
end
-- 退出战斗
function BattleUIResultPop:colseBattle()
    if self._quit then
        self._quit()
    end
    self:hide({noAction = true})
end

---------------------通用 end---------------------

return BattleUIResultPop
