--[[
	选服弹窗
	唐实聪
	2016.5.7
    zc.createSourcePop( "SelectServerPop", "src/layer/login/SelectServerPop.lua", data )
]]
local SelectServerPop = class("SelectServerPop", function()
	return ZCPopLayer:create({isRemoveLayout = false})
end)

function SelectServerPop:onCleanup()   
    local textureCache = cc.Director:getInstance():getTextureCache()
    textureCache:removeTextureForKey("res/Main/login/login_bg1.png")
    textureCache:removeTextureForKey("res/Main/login/login_select2.png")
    textureCache:removeTextureForKey("res/Main/login/login_select1.png")
    textureCache:removeTextureForKey("res/Main/login/login_line1.png")
    textureCache:removeTextureForKey("res/Main/login/login_bg2.png")
    textureCache:removeTextureForKey("res/Main/login/login_bg3.png")
    textureCache:removeTextureForKey("res/Main/login/login_line2.png")
end

function SelectServerPop:create( params )
	return SelectServerPop.new( params )
end

function SelectServerPop:ctor( params )
	self:initData( params )
    if #self._serverList > 0 then
        self._exist = true
        self:show()
    	self:initUI()
        self:refreshServers()
    else
        self._exist = false
    end
end

function SelectServerPop:initData( params )
    -- dump( params, "params" )
	-- 100个区放到一起
	self._serverUnit = 100
	-- 服务器列表index，从0开始
	self._unitIndex = 1

    self._lastServer = params.lastLogin

    self._serverList = {}
    local serverUnitNum = 0
    for i, v in ipairs( params.list or {} ) do
        local _tab = tonumber(v.tab) or 1
        local index = math.modf(tonumber( _tab )/self._serverUnit)
        index = index + 1
        self._serverList[index] = self._serverList[index] or {}
        self._serverList[index][#self._serverList[index] + 1] = v
        serverUnitNum = serverUnitNum > index and serverUnitNum or index
    end
    for i, v in ipairs( self._serverList ) do
        table.sort(v, function( a, b )
            -- if not a or not b then
            --     return false
            -- end
            local _tab1 = tonumber( a.serverId ) or 1
            local _tab2 = tonumber( b.serverId ) or 1
            return _tab1 > _tab2
        end)
    end
    for i = 1, serverUnitNum do
        self._serverList[i] = self._serverList[i] or {}
    end
    -- dump( self._serverList, "self._serverList" )
    -- 服务器index
    self._serverIndex = 1


	self._size = self:getContentSize()
end

function SelectServerPop:initUI()
	-- 背景
	local bg = cc.Sprite:create()
	bg:setContentSize( self._size )
    bg:setPosition( self._size.width/2, self._size.height/2 )
	self:addContent( bg )
	self._bg = bg

	self:initAllServer()
	self:initLastServer()
	self:initServers()
end
-- 所有服务器
function SelectServerPop:initAllServer()
	-- 所有服务器
	local allServerBg = cc.Sprite:create( "res/Main/login/login_bg1.png" )
	allServerBg:setPosition( self._size.width/2 - 360, self._size.height/2 )
	self._bg:addChild( allServerBg )
	self._allServerBg = allServerBg
	local allServerBgSize = allServerBg:getContentSize()
	-- 所有服务器标题
	local allServerTitle = zc.createLabel({
        text = zc.lang("all_server"),
        fontSize = 25,
        pos = cc.p( allServerBgSize.width/2, allServerBgSize.height - 40 ),
        color = cc.c3b( 250, 150, 70 ),
    })
    allServerBg:addChild( allServerTitle )
    -- tableview
    local serverData = {
    	zc.lang("recommend"),
	}
    for i = 1, #self._serverList do
    	serverData[i + 1] = ( ( i - 1 )*self._serverUnit + 1 ).."--"..( i*self._serverUnit ).. zc.lang("area")
    end
    -- cell尺寸
    local cellWidth = allServerBgSize.width
    local cellHeight = 60
    -- tableview内部高度
    local innerHeight = ( #serverData*cellHeight )
    -- 可显示高度
    local limitHeight = ( allServerBgSize.height - 60 )
    local overFlag = false
    if innerHeight > limitHeight then
    	-- 超出
    	overFlag = true
	else
		-- 未超出
		overFlag = false
	end
	-- tableview
    local tableview = zc.ZCTableView:create( cc.size( cellWidth, limitHeight ) )
    tableview:setBounceable( overFlag )
    tableview:setInertia( true )
    tableview:setDirection( cc.SCROLLVIEW_DIRECTION_VERTICAL )
    tableview:setPosition( cc.p( 0, 10 ) )
    tableview:setDelegate()
    tableview:setVerticalFillOrder( cc.TABLEVIEW_FILL_TOPDOWN )
    local function tableCellTouched(table, cell)
    	if self._unitIndex ~= cell:getIdx() then
	    	if self._selectedUnit then
	    		self._selectedUnit._selected:setVisible( false )
	    	end
	    	cell._selected:setVisible( true )
	    	self._selectedUnit = cell
	    	self._unitIndex = cell:getIdx()
            self:refreshServers()
	    end
    end
    local function cellSizeForTable(table, index) 
        return cellHeight, cellWidth
    end
    local function tableCellAtIndex(table, index)
        local cell = table:dequeueCell()
        -- 创建模板
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
        end
        cell:removeAllChildren()
        -- selected
        local selected = cc.Sprite:create( "res/Main/login/login_select2.png" )
        selected:setPosition( cellWidth/2, cellHeight/2 )
        cell:addChild( selected )
        cell._selected = selected
        -- label
        local label = zc.createLabel({
        	text = serverData[index + 1],
	        fontSize = 25,
	        pos = cc.p( cellWidth/2, cellHeight/2 ),
	        color = display.COLOR_WHITE,
            shadow = true
    	})
    	cell:addChild( label )
    	-- split
    	local split = cc.Sprite:create( "res/Main/login/login_line1.png" )
    	split:setPosition( cellWidth/2, 0 )
    	cell:addChild( split )

    	if self._unitIndex == index then
    		self._selectedUnit = cell
    	else
    		selected:setVisible( false )
    	end

        return cell
    end
    local function numberOfCellsInTableView()
        return #serverData
    end
    tableview:registerScriptHandler(tableCellTouched, cc.TABLECELL_TOUCHED)
    tableview:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX)
    tableview:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX)
    tableview:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    allServerBg:addChild( tableview )
    tableview:reloadData()
end
-- 上次登录服务器
function SelectServerPop:initLastServer()
	-- 上次登录服务器
	local lastServerBg = cc.Sprite:create( "res/Main/login/login_bg2.png" )
	lastServerBg:setPosition( self._size.width/2 + 128, self._size.height/2 + 220 )
	self._bg:addChild( lastServerBg )
	self._lastServerBg = lastServerBg
	local lastServerBgSize = lastServerBg:getContentSize()
	-- 上次登录服务器
	local lastServerLabel = zc.createLabel({
        text = zc.lang("last_login_server"),
        fontSize = 25,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 30, lastServerBgSize.height/2 ),
        color = cc.c3b( 250, 150, 70 )
    })
    self._lastServerBg:addChild( lastServerLabel )
    -- 
    if self._lastServer then
        local stateText, stateColor = LANGUAGE_get_server_status_name(self._lastServer.status)
        
        -- serverId
        local _tab = tonumber(self._lastServer.tab) or 1
        local serverId = zc.createLabel({
            text = _tab.. zc.lang("area"),
            fontSize = 25,
            ap = cc.p( 0, 0.5 ),
            pos = cc.p( 310, lastServerBgSize.height/2 ),
            color = stateColor
        })
        self._lastServerBg:addChild( serverId )
        -- serverName
        local serverName = zc.createLabel({
            text = self._lastServer.name,
            fontSize = 25,
            ap = cc.p( 0, 0.5 ),
            pos = cc.p( 390, lastServerBgSize.height/2 ),
            color = stateColor
        })
        self._lastServerBg:addChild( serverName )
        -- serverState
        if stateText ~= "" then
            local serverState = zc.createLabel({
                text = stateText,
                fontSize = 25,
                ap = cc.p( 0, 0.5 ),
                pos = cc.p( 525, lastServerBgSize.height/2 ),
                color = stateColor
            })
            self._lastServerBg:addChild( serverState )
        end
        -- btn
        local btn = zc.createPushButton({
            touchSize = lastServerBgSize,
            pos = cc.p( lastServerBgSize.width/2, lastServerBgSize.height/2 ),
            endCallback = function()
                self:setServerData( self._lastServer )
                self:hide()
            end
        })
        self._lastServerBg:addChild( btn )
    end
end
-- 当前区间服务器
function SelectServerPop:initServers()
	local serversBg = cc.Sprite:create( "res/Main/login/login_bg3.png" )
	serversBg:setPosition( self._size.width/2 + 128, self._size.height/2 - 40 )
	self._bg:addChild( serversBg )
	self._serversBg = serversBg
	local serversBgSize = serversBg:getContentSize()
	-- 服务器区间
	local serversTitle = zc.createLabel({
        fontSize = 25,
        pos = cc.p( serversBgSize.width/2, serversBgSize.height - 40 ),
        color = cc.c3b( 250, 150, 70 ),
    })
    serversBg:addChild( serversTitle )
    self._serversTitle = serversTitle
    -- 分隔线
    local splitLine = cc.Sprite:create( "res/Main/login/login_line2.png" )
    splitLine:setPosition( serversBgSize.width/2, serversBgSize.height - 65 )
    splitLine:setScaleX( 2.4 )
    splitLine:setScaleY( 2 )
    serversBg:addChild( splitLine )
    -- tableview
    local cellWidth = serversBgSize.width
    local cellHeight = 60
    local tableview = zc.ZCTableView:create( cc.size( cellWidth, serversBgSize.height - 80 ) )
    tableview:setBounceable( true )
    tableview:setInertia( true )
    tableview:setDirection( cc.SCROLLVIEW_DIRECTION_VERTICAL )
    tableview:setPosition( cc.p( 0, 10 ) )
    tableview:setDelegate()
    tableview:setVerticalFillOrder( cc.TABLEVIEW_FILL_TOPDOWN )
    local function cellSizeForTable(table, index) 
        return cellHeight, cellWidth
    end
    local function tableCellAtIndex(table, index)
        local cell = table:dequeueCell()
        -- 创建模板
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
        end
        cell:removeAllChildren()
        cell._selected = {}
        for i = 1, 2 do
            -- data
            local data = nil
            if self._unitIndex == 0 then
                data = nil
            else
                data = self._serverList[self._unitIndex][index*2 + i]
            end
            if data then
                -- dump( data, "data" )
                local stateText, stateColor = LANGUAGE_get_server_status_name(data.status)
                -- cellBg
                local cellBg = cc.Sprite:create()
                cellBg:setContentSize( cellWidth/2, cellHeight )
                cellBg:setPosition( cellWidth/4*( 2*i - 1 ), cellHeight/2 )
                cell:addChild( cellBg )
                local cellBgSize = cellBg:getContentSize()
                -- selected
                local selected = cc.Sprite:create( "res/Main/login/login_select1.png" )
                selected:setPosition( cellBgSize.width/2, cellBgSize.height/2 )
                cellBg:addChild( selected )
                cell._selected[i] = selected
                -- serverId
                local _tab = tonumber(data.tab) or 1
                local serverId = zc.createLabel({
                    text = _tab .. zc.lang("area"),
                    fontSize = 25,
                    ap = cc.p( 0, 0.5 ),
                    pos = cc.p( 35, cellBgSize.height/2 ),
                    color = stateColor,
                    shadow = true
                })
                cellBg:addChild( serverId )
                -- serverName
                local serverName = zc.createLabel({
                    text = data.name,
                    fontSize = 25,
                    ap = cc.p( 0, 0.5 ),
                    pos = cc.p( 115, cellBgSize.height/2 ),
                    color = stateColor,
                    shadow = true
                })
                cellBg:addChild( serverName )
                -- serverState
                if stateText ~= "" then
                    local serverState = zc.createLabel({
                        text = stateText,
                        fontSize = 25,
                        ap = cc.p( 0, 0.5 ),
                        pos = cc.p( 250, cellBgSize.height/2 ),
                        color = stateColor,
                        shadow = true
                    })
                    cellBg:addChild( serverState )
                end
            	-- split
            	local split = cc.Sprite:create( "res/Main/login/login_line1.png" )
            	split:setPosition( cellBgSize.width/2, 0 )
            	cellBg:addChild( split )
                if self._serverIndex == 2*index + i then
                    self._selectedServer = cell
                else
                    selected:setVisible( false )
                end
                -- btn
                local btn = zc.createPushButton({
                    touchSize = cellBgSize,
                    pos = cc.p( cellBgSize.width/2, cellBgSize.height/2 ),
                    needSwallow = false,
                    needEnableWhenMoving = false,
                    endCallback = function()
                        if self._serverIndex ~= 2*index + i then
                            if self._selectedServer then
                                local cellIndex = ( self._serverIndex - 1 )%2 + 1
                                if self._selectedServer._selected[cellIndex] then
                                    self._selectedServer._selected[cellIndex]:setVisible( false )
                                end
                            end
                            self._selectedServer = cell
                            selected:setVisible( true )
                            self._serverIndex = 2*index + i
                        end
                        self:setServerData( data )
                        self:hide()
                    end
                })
                btn:setSwallowTouches(false)
                cellBg:addChild( btn )
            end
        end

        return cell
    end
    local function numberOfCellsInTableView()
        if self._unitIndex == 0 then
            return 0
        else
            return math.ceil(#self._serverList[self._unitIndex]/2)
        end
    end
    local function tableCellTouched(table, cell)
    end
    tableview:registerScriptHandler(tableCellTouched, cc.TABLECELL_TOUCHED)
    tableview:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX)
    tableview:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX)
    tableview:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    serversBg:addChild( tableview )
    self._serversTableview = tableview
end

function SelectServerPop:refreshServers()
    self._serverIndex = 1
    local titleText = zc.lang("server") .. "  "
    if self._unitIndex == 0 then
        titleText = titleText .. zc.lang("recommend")
    else
        titleText = titleText..( ( self._unitIndex - 1 )*self._serverUnit + 1 ).."--"..( self._unitIndex*self._serverUnit )
    end
    self._serversTitle:setText( titleText )
    self._serversTableview:reloadData()
end
-- 选服设置数据
function SelectServerPop:setServerData( data )
    zc.dispatchEvent({ name = CUSTOM_EVENT.EVENT_SELECT_SERVER, data = {server= data}, })
end


return SelectServerPop